.. _release_and_maintenance:

************************
Releases and maintenance
************************

.. _release_cycle:
.. _release_schedule:
.. _support_life:
.. _methods:
.. _release_freezing:
.. _development_and_stable_version_maintenance_workflow:
.. _release_changelogs:

Please go to `the devel release and maintenance page <https://docs.ansible.com/ansible/devel/reference_appendices/release_and_maintenance.html>`_ for up to date information.

.. note::

	This link takes you to a different version of the Ansible documentation. Use the version selection on the left or your browser back button to return to this version of the documentation.

.. seealso::

   :ref:`community_committer_guidelines`
       Guidelines for Ansible core contributors and maintainers
   :ref:`testing_strategies`
       Testing strategies
   :ref:`ansible_community_guide`
       Community information and contributing
   `Development Mailing List <https://groups.google.com/group/ansible-devel>`_
       Mailing list for development topics
   `irc.libera.chat <https://libera.chat/>`_
       #ansible IRC chat channel
